<?php
namespace Avalara\AvaTaxRestV2;
/*****************************************************************************
 *                                                                           *
 *      This file is automatically generated by the AvaTax SDK process.      *
 *                  Edits to this file will be overwritten.                  *
 *                                                                           *
 *****************************************************************************/
 
/*****************************************************************************
 *                              Enumerated constants                         *
 *****************************************************************************/

 /**
 * Lists of acceptable values for the enumerated data type TransactionAddressType
 */
class TransactionAddressType
{
    const C_SHIPFROM = "ShipFrom";
    const C_SHIPTO = "ShipTo";
    const C_POINTOFORDERACCEPTANCE = "PointOfOrderAcceptance";
    const C_POINTOFORDERORIGIN = "PointOfOrderOrigin";
    const C_SINGLELOCATION = "SingleLocation";
}


/**
 * Casing to use for validation result
 */
class TextCase
{

    /**
     * Upper case
     */
    const C_UPPER = "Upper";

    /**
     * Mixed Case
     */
    const C_MIXED = "Mixed";

}


/**
 * Represents the different types of transactions that AvaTax can process.
 */
class DocumentType
{

    /**
     * Represents an estimate, or a sales order, or a quote. 
     *  
     *  This document type is used before a sale has occurred to estimate the final amount of tax to be paid when the
     *  sale is completed.
     *  
     *  For a sales order, the `companyCode` of the transaction refers to the seller and the `customerVendorCode` refers to the buyer.
     *  
     *  This is a temporary document type and is not saved in tax history.
     */
    const C_SALESORDER = "SalesOrder";

    /**
     * Represents a sale that has been finalized.
     *  
     *  This document type is used to record a final transaction and calculate the final tax amount with all necessary information.
     *  
     *  For a sales invoice, the `companyCode` of the transaction refers to the seller and the `customerVendorCode` refers to the buyer.
     *  
     *  This is a permanent document and is recorded in AvaTax.
     */
    const C_SALESINVOICE = "SalesInvoice";

    /**
     * Represents an estimate, or a purchase order, or a quote.
     *  
     *  This document type is used before a sale has occurred to estimate the final amount of tax to be paid when the
     *  sale is completed.
     *  
     *  For a purchase order, the `companyCode` of the transaction refers to the buyer and the `customerVendorCode` refers to the seller.
     *  
     *  This is a temporary document type and is not saved in tax history.
     */
    const C_PURCHASEORDER = "PurchaseOrder";

    /**
     * Represents a sale that has been finalized.
     *  
     *  This document type is used to record a final transaction and calculate the final tax amount with all necessary information.
     *  
     *  For a purchase invoice, the `companyCode` of the transaction refers to the buyer and the `customerVendorCode` refers to the seller.
     *  
     *  This is a permanent document and is recorded in AvaTax.
     */
    const C_PURCHASEINVOICE = "PurchaseInvoice";

    /**
     * Represents an estimate of tax to be refunded if a refund or return is processed.
     *  
     *  This document type is used before a customer chooses to request a refund for a previous sale, and it
     *  estimates the final amount of tax to be refunded when the refund is completed.
     *  
     *  For a return order, the `companyCode` of the transaction refers to the seller who is giving the refund 
     *  and the `customerVendorCode` refers to the buyer who is requesting the refund.
     *  
     *  This is a temporary document type and is not saved in tax history.
     */
    const C_RETURNORDER = "ReturnOrder";

    /**
     * Represents an refund that has been finalized.
     *  
     *  This document type is used when a customer chooses to request a refund for a previous sale, and it
     *  records the final amount of tax that has been refunded when the refund is completed.
     *  
     *  For a return invoice, the `companyCode` of the transaction refers to the seller who is giving the refund 
     *  and the `customerVendorCode` refers to the buyer who is requesting the refund.
     *  
     *  This is a permanent document and is recorded in AvaTax.
     *  
     *  Please note that many jurisdictions around the United States have special rules about how to report refunds
     *  on a sales tax filing, and some refund transactions may be unable to file immediately due to credit netting
     *  rules.
     */
    const C_RETURNINVOICE = "ReturnInvoice";

    /**
     * Represents a proposed movement of inventory from one jurisdiction to another.
     *  
     *  This document type is used when physical goods are shipped from one jurisdiction to another, and it
     *  may cause updates in the tax liability for various jurisdictions.
     *  
     *  For an inventory transfer invoice, the `companyCode` of the transaction refers to the owner of the inventory
     *  that will be moved from one location to another.
     *  
     *  This is a temporary document type and is not saved in tax history.
     */
    const C_INVENTORYTRANSFERORDER = "InventoryTransferOrder";

    /**
     * Represents a movement of inventory from one jurisdiction to another that has been finalized.
     *  
     *  This document type is used when physical goods are shipped from one jurisdiction to another, and it
     *  may cause updates in the tax liability for various jurisdictions.
     *  
     *  For an inventory transfer invoice, the `companyCode` of the transaction refers to the owner of the inventory
     *  that will be moved from one location to another.
     *  
     *  This is a permanent document and is recorded in AvaTax.
     */
    const C_INVENTORYTRANSFERINVOICE = "InventoryTransferInvoice";

    /**
     * Represents a VAT "Reverse Charge" mechanism transaction as defined in the European Union.
     *  
     *  A Reverse Charge transaction moves the responsibility for VAT reporting from the seller to the buyer, and
     *  is intended to allow simplification of commerce and reduce the reporting requirements for sellers that deliver
     *  goods and services into the single market.
     *  
     *  This is a temporary document type and is not saved in tax history.
     */
    const C_REVERSECHARGEORDER = "ReverseChargeOrder";

    /**
     * Represents a VAT "Reverse Charge" mechanism transaction as defined in the European Union.
     *  
     *  A Reverse Charge transaction moves the responsibility for VAT reporting from the seller to the buyer, and
     *  is intended to allow simplification of commerce and reduce the reporting requirements for sellers that deliver
     *  goods and services into the single market.
     *  
     *  This is a permanent document and is recorded in AvaTax.
     */
    const C_REVERSECHARGEINVOICE = "ReverseChargeInvoice";

    /**
     * Not a real document type.
     *  
     *  This value is used when querying for documents. You can specify the type `Any` in some cases to permit the
     *  system to find any document matching other criteria.
     */
    const C_ANY = "Any";

}


/**
 * Type of certificate preview to download
 */
class CertificatePreviewType
{

    /**
     * Download a full printable PDF
     */
    const C_PDF = "Pdf";

    /**
     * Download a single page of the certificate in JPG format
     */
    const C_JPEG = "Jpeg";

}


/**
 * Filing Frequency types
 */
class FilingFrequencyId
{

    /**
     * File once per month
     */
    const C_MONTHLY = "Monthly";

    /**
     * File once per three months
     */
    const C_QUARTERLY = "Quarterly";

    /**
     * File twice per year
     */
    const C_SEMIANNUALLY = "SemiAnnually";

    /**
     * File once per year
     */
    const C_ANNUALLY = "Annually";

    /**
     * File every other month
     */
    const C_BIMONTHLY = "Bimonthly";

    /**
     * File only when there are documents to report
     */
    const C_OCCASIONAL = "Occasional";

    /**
     * File for the first two months of each quarter, then do not file on the quarterly month.
     */
    const C_INVERSEQUARTERLY = "InverseQuarterly";

}


/**
 * Filing Status
 */
class FilingStatusId
{
    const C_PENDINGAPPROVAL = "PendingApproval";
    const C_DIRTY = "Dirty";
    const C_APPROVEDTOFILE = "ApprovedToFile";
    const C_PENDINGFILING = "PendingFiling";
    const C_PENDINGFILINGONBEHALF = "PendingFilingOnBehalf";
    const C_FILED = "Filed";
    const C_FILEDONBEHALF = "FiledOnBehalf";
    const C_RETURNACCEPTED = "ReturnAccepted";
    const C_RETURNACCEPTEDONBEHALF = "ReturnAcceptedOnBehalf";
    const C_PAYMENTREMITTED = "PaymentRemitted";
    const C_VOIDED = "Voided";
    const C_PENDINGRETURN = "PendingReturn";
    const C_PENDINGRETURNONBEHALF = "PendingReturnOnBehalf";
    const C_DONOTFILE = "DoNotFile";
    const C_RETURNREJECTED = "ReturnRejected";
    const C_RETURNREJECTEDONBEHALF = "ReturnRejectedOnBehalf";
    const C_APPROVEDTOFILEONBEHALF = "ApprovedToFileOnBehalf";

}


/**
 * Type of file request
 */
class PointOfSaleFileType
{

    /**
     * File is in Javascript Object Notation format
     */
    const C_JSON = "Json";

    /**
     * File is in Comma Separated Values format
     */
    const C_CSV = "Csv";

    /**
     * File is in Extended Markup Language format
     */
    const C_XML = "Xml";

}


/**
 * 
 */
class PointOfSalePartnerId
{
    const C_DMA = "DMA";
    const C_AX7 = "AX7";

}


/**
 * Represents the type of service or subscription given to a user
 */
class ServiceTypeId
{

    /**
     * None
     */
    const C_NONE = "None";

    /**
     * AvaTaxST
     */
    const C_AVATAXST = "AvaTaxST";

    /**
     * AvaTaxPro
     */
    const C_AVATAXPRO = "AvaTaxPro";

    /**
     * AvaTaxGlobal
     */
    const C_AVATAXGLOBAL = "AvaTaxGlobal";

    /**
     * AutoAddress
     */
    const C_AUTOADDRESS = "AutoAddress";

    /**
     * AutoReturns
     */
    const C_AUTORETURNS = "AutoReturns";

    /**
     * TaxSolver
     */
    const C_TAXSOLVER = "TaxSolver";

    /**
     * AvaTaxCsp
     */
    const C_AVATAXCSP = "AvaTaxCsp";

    /**
     * Twe
     */
    const C_TWE = "Twe";

    /**
     * Mrs
     */
    const C_MRS = "Mrs";

    /**
     * AvaCert
     */
    const C_AVACERT = "AvaCert";

    /**
     * AuthorizationPartner
     */
    const C_AUTHORIZATIONPARTNER = "AuthorizationPartner";

    /**
     * CertCapture
     */
    const C_CERTCAPTURE = "CertCapture";

    /**
     * AvaUpc
     */
    const C_AVAUPC = "AvaUpc";

    /**
     * AvaCUT
     */
    const C_AVACUT = "AvaCUT";

    /**
     * AvaLandedCost
     */
    const C_AVALANDEDCOST = "AvaLandedCost";

    /**
     * AvaLodging
     */
    const C_AVALODGING = "AvaLodging";

    /**
     * AvaBottle
     */
    const C_AVABOTTLE = "AvaBottle";

    /**
     * MRSComplianceManager
     */
    const C_MRSCOMPLIANCEMANAGER = "MRSComplianceManager";

}


/**
 * Status of an Avalara account
 */
class AccountStatusId
{

    /**
     * This account is not currently active.
     */
    const C_INACTIVE = "Inactive";

    /**
     * This account is active and in use.
     */
    const C_ACTIVE = "Active";

    /**
     * This account is flagged as a test account and may be temporary.
     */
    const C_TEST = "Test";

    /**
     * The account is new and is currently in the onboarding process.
     */
    const C_NEW = "New";

}


/**
 * Permission level of a user
 */
class SecurityRoleId
{

    /**
     * NoAccess
     */
    const C_NOACCESS = "NoAccess";

    /**
     * SiteAdmin
     */
    const C_SITEADMIN = "SiteAdmin";

    /**
     * AccountOperator
     */
    const C_ACCOUNTOPERATOR = "AccountOperator";

    /**
     * AccountAdmin
     */
    const C_ACCOUNTADMIN = "AccountAdmin";

    /**
     * AccountUser
     */
    const C_ACCOUNTUSER = "AccountUser";

    /**
     * SystemAdmin
     */
    const C_SYSTEMADMIN = "SystemAdmin";

    /**
     * Registrar
     */
    const C_REGISTRAR = "Registrar";

    /**
     * CSPTester
     */
    const C_CSPTESTER = "CSPTester";

    /**
     * CSPAdmin
     */
    const C_CSPADMIN = "CSPAdmin";

    /**
     * SystemOperator
     */
    const C_SYSTEMOPERATOR = "SystemOperator";

    /**
     * TechnicalSupportUser
     */
    const C_TECHNICALSUPPORTUSER = "TechnicalSupportUser";

    /**
     * TechnicalSupportAdmin
     */
    const C_TECHNICALSUPPORTADMIN = "TechnicalSupportAdmin";

    /**
     * TreasuryUser
     */
    const C_TREASURYUSER = "TreasuryUser";

    /**
     * TreasuryAdmin
     */
    const C_TREASURYADMIN = "TreasuryAdmin";

    /**
     * ComplianceUser
     */
    const C_COMPLIANCEUSER = "ComplianceUser";

    /**
     * ComplianceAdmin
     */
    const C_COMPLIANCEADMIN = "ComplianceAdmin";

    /**
     * ProStoresOperator
     */
    const C_PROSTORESOPERATOR = "ProStoresOperator";

    /**
     * CompanyUser
     */
    const C_COMPANYUSER = "CompanyUser";

    /**
     * CompanyAdmin
     */
    const C_COMPANYADMIN = "CompanyAdmin";

    /**
     * ComplianceTempUser
     */
    const C_COMPLIANCETEMPUSER = "ComplianceTempUser";

    /**
     * ComplianceRootUser
     */
    const C_COMPLIANCEROOTUSER = "ComplianceRootUser";

    /**
     * ComplianceOperator
     */
    const C_COMPLIANCEOPERATOR = "ComplianceOperator";

    /**
     * SSTAdmin
     */
    const C_SSTADMIN = "SSTAdmin";

}


/**
 * PasswordStatusId
 */
class PasswordStatusId
{

    /**
     * UserCannotChange
     */
    const C_USERCANNOTCHANGE = "UserCannotChange";

    /**
     * UserCanChange
     */
    const C_USERCANCHANGE = "UserCanChange";

    /**
     * UserMustChange
     */
    const C_USERMUSTCHANGE = "UserMustChange";

}


/**
 * Represents a error code message
 */
class ErrorCodeId
{

    /**
     * Server has a configuration or setup problem
     */
    const C_SERVERCONFIGURATION = "ServerConfiguration";

    /**
     * User doesn't have rights to this account or company
     */
    const C_ACCOUNTINVALIDEXCEPTION = "AccountInvalidException";
    const C_COMPANYINVALIDEXCEPTION = "CompanyInvalidException";

    /**
     * Use this error message when the user is trying to fetch a single object and the object either does not exist or cannot be seen by the current user.
     */
    const C_ENTITYNOTFOUNDERROR = "EntityNotFoundError";
    const C_VALUEREQUIREDERROR = "ValueRequiredError";
    const C_RANGEERROR = "RangeError";
    const C_RANGECOMPAREERROR = "RangeCompareError";
    const C_RANGESETERROR = "RangeSetError";
    const C_TAXPAYERNUMBERREQUIRED = "TaxpayerNumberRequired";
    const C_COMMONPASSWORD = "CommonPassword";
    const C_WEAKPASSWORD = "WeakPassword";
    const C_STRINGLENGTHERROR = "StringLengthError";
    const C_MAXSTRINGLENGTHERROR = "MaxStringLengthError";
    const C_EMAILVALIDATIONERROR = "EmailValidationError";
    const C_EMAILMISSINGERROR = "EmailMissingError";
    const C_PARSERFIELDNAMEERROR = "ParserFieldNameError";
    const C_PARSERFIELDVALUEERROR = "ParserFieldValueError";
    const C_PARSERSYNTAXERROR = "ParserSyntaxError";
    const C_PARSERTOOMANYPARAMETERSERROR = "ParserTooManyParametersError";
    const C_PARSERUNTERMINATEDVALUEERROR = "ParserUnterminatedValueError";
    const C_DELETEUSERSELFERROR = "DeleteUserSelfError";
    const C_OLDPASSWORDINVALID = "OldPasswordInvalid";
    const C_CANNOTCHANGEPASSWORD = "CannotChangePassword";
    const C_CANNOTCHANGECOMPANYCODE = "CannotChangeCompanyCode";
    const C_DATEFORMATERROR = "DateFormatError";
    const C_NODEFAULTCOMPANY = "NoDefaultCompany";
    const C_AUTHENTICATIONEXCEPTION = "AuthenticationException";
    const C_AUTHORIZATIONEXCEPTION = "AuthorizationException";
    const C_VALIDATIONEXCEPTION = "ValidationException";
    const C_INACTIVEUSERERROR = "InactiveUserError";
    const C_AUTHENTICATIONINCOMPLETE = "AuthenticationIncomplete";
    const C_BASICAUTHINCORRECT = "BasicAuthIncorrect";
    const C_IDENTITYSERVERERROR = "IdentityServerError";
    const C_BEARERTOKENINVALID = "BearerTokenInvalid";
    const C_MODELREQUIREDEXCEPTION = "ModelRequiredException";
    const C_ACCOUNTEXPIREDEXCEPTION = "AccountExpiredException";
    const C_VISIBILITYERROR = "VisibilityError";
    const C_BEARERTOKENNOTSUPPORTED = "BearerTokenNotSupported";
    const C_INVALIDSECURITYROLE = "InvalidSecurityRole";
    const C_INVALIDREGISTRARACTION = "InvalidRegistrarAction";
    const C_REMOTESERVERERROR = "RemoteServerError";
    const C_NOFILTERCRITERIAEXCEPTION = "NoFilterCriteriaException";
    const C_OPENCLAUSEEXCEPTION = "OpenClauseException";
    const C_JSONFORMATERROR = "JsonFormatError";
    const C_UNHANDLEDEXCEPTION = "UnhandledException";
    const C_REPORTINGCOMPANYMUSTHAVECONTACTSERROR = "ReportingCompanyMustHaveContactsError";
    const C_COMPANYPROFILENOTSET = "CompanyProfileNotSet";
    const C_CANNOTASSIGNUSERTOCOMPANY = "CannotAssignUserToCompany";
    const C_MUSTASSIGNUSERTOCOMPANY = "MustAssignUserToCompany";
    const C_MODELSTATEINVALID = "ModelStateInvalid";
    const C_DATERANGEERROR = "DateRangeError";
    const C_INVALIDDATERANGEERROR = "InvalidDateRangeError";
    const C_DELETEINFORMATION = "DeleteInformation";
    const C_CANNOTCREATEDELETEDOBJECTS = "CannotCreateDeletedObjects";
    const C_CANNOTMODIFYDELETEDOBJECTS = "CannotModifyDeletedObjects";
    const C_RETURNNAMENOTFOUND = "ReturnNameNotFound";
    const C_INVALIDADDRESSTYPEANDCATEGORY = "InvalidAddressTypeAndCategory";
    const C_DEFAULTCOMPANYLOCATION = "DefaultCompanyLocation";
    const C_INVALIDCOUNTRY = "InvalidCountry";
    const C_INVALIDCOUNTRYREGION = "InvalidCountryRegion";
    const C_BRAZILVALIDATIONERROR = "BrazilValidationError";
    const C_BRAZILEXEMPTVALIDATIONERROR = "BrazilExemptValidationError";
    const C_BRAZILPISCOFINSERROR = "BrazilPisCofinsError";
    const C_JURISDICTIONNOTFOUNDERROR = "JurisdictionNotFoundError";
    const C_MEDICALEXCISEERROR = "MedicalExciseError";
    const C_RATEDEPENDSTAXABILITYERROR = "RateDependsTaxabilityError";
    const C_RATEDEPENDSEUROPEERROR = "RateDependsEuropeError";
    const C_INVALIDRATETYPECODE = "InvalidRateTypeCode";
    const C_RATETYPENOTSUPPORTED = "RateTypeNotSupported";
    const C_CANNOTUPDATENESTEDOBJECTS = "CannotUpdateNestedObjects";
    const C_UPCCODEINVALIDCHARS = "UPCCodeInvalidChars";
    const C_UPCCODEINVALIDLENGTH = "UPCCodeInvalidLength";
    const C_INCORRECTPATHERROR = "IncorrectPathError";
    const C_INVALIDJURISDICTIONTYPE = "InvalidJurisdictionType";
    const C_MUSTCONFIRMRESETLICENSEKEY = "MustConfirmResetLicenseKey";
    const C_DUPLICATECOMPANYCODE = "DuplicateCompanyCode";
    const C_TINFORMATERROR = "TINFormatError";
    const C_DUPLICATENEXUSERROR = "DuplicateNexusError";
    const C_UNKNOWNNEXUSERROR = "UnknownNexusError";
    const C_PARENTNEXUSNOTFOUND = "ParentNexusNotFound";
    const C_INVALIDTAXCODETYPE = "InvalidTaxCodeType";
    const C_CANNOTACTIVATECOMPANY = "CannotActivateCompany";
    const C_DUPLICATEENTITYPROPERTY = "DuplicateEntityProperty";
    const C_REPORTINGENTITYERROR = "ReportingEntityError";
    const C_INVALIDRETURNOPERATIONERROR = "InvalidReturnOperationError";
    const C_CANNOTDELETECOMPANY = "CannotDeleteCompany";
    const C_COUNTRYOVERRIDESNOTAVAILABLE = "CountryOverridesNotAvailable";
    const C_JURISDICTIONOVERRIDEMISMATCH = "JurisdictionOverrideMismatch";
    const C_DUPLICATESYSTEMTAXCODE = "DuplicateSystemTaxCode";
    const C_SSTOVERRIDESNOTAVAILABLE = "SSTOverridesNotAvailable";
    const C_NEXUSDATEMISMATCH = "NexusDateMismatch";
    const C_TECHSUPPORTAUDITREQUIRED = "TechSupportAuditRequired";
    const C_NEXUSPARENTDATEMISMATCH = "NexusParentDateMismatch";
    const C_BEARERTOKENPARSEUSERIDERROR = "BearerTokenParseUserIdError";
    const C_RETRIEVEUSERERROR = "RetrieveUserError";
    const C_INVALIDCONFIGURATIONSETTING = "InvalidConfigurationSetting";
    const C_INVALIDCONFIGURATIONVALUE = "InvalidConfigurationValue";
    const C_INVALIDENUMVALUE = "InvalidEnumValue";
    const C_TAXCODEASSOCIATEDTAXRULE = "TaxCodeAssociatedTaxRule";
    const C_CANNOTSWITCHACCOUNTID = "CannotSwitchAccountId";
    const C_REQUESTINCOMPLETE = "RequestIncomplete";
    const C_ACCOUNTNOTNEW = "AccountNotNew";
    const C_PASSWORDLENGTHINVALID = "PasswordLengthInvalid";
    const C_LOCALNEXUSCONFLICT = "LocalNexusConflict";
    const C_INVALIDECMSOVERRIDECODE = "InvalidEcmsOverrideCode";
    const C_ACCOUNTDOESNOTEXIST = "AccountDoesNotExist";
    const C_INVALIDTAXTYPE = "InvalidTaxType";
    const C_INCORRECTFIELDVALUE = "IncorrectFieldValue";
    const C_LEADINGORTRAILINGEXCEPTION = "LeadingOrTrailingException";
    const C_NOTENOUGHADDRESSESINFO = "NotEnoughAddressesInfo";
    const C_REPORTNOTINITIATED = "ReportNotInitiated";
    const C_FAILEDTOBUILDREPORT = "FailedToBuildReport";
    const C_REPORTNOTFINISHED = "ReportNotFinished";
    const C_FAILEDTOUPLOADREPORT = "FailedToUploadReport";
    const C_FAILEDTODOWNLOADREPORT = "FailedToDownloadReport";
    const C_MALFORMEDFILTEREXCEPTION = "MalformedFilterException";
    const C_EXPECTEDCONJUNCTIONERROR = "ExpectedConjunctionError";
    const C_CRITERIANOTSUPPORTEDERROR = "CriteriaNotSupportedError";
    const C_COMPANYACCOUNTANDPARENTACCOUNTMISMATCH = "CompanyAccountAndParentAccountMismatch";
    const C_INVALIDFILECONTENTTYPE = "InvalidFileContentType";
    const C_ECMSDISABLED = "EcmsDisabled";
    const C_UNKNOWNCONJUNCTIONERROR = "UnknownConjunctionError";
    const C_NOLINESDISCOUNTED = "NoLinesDiscounted";
    const C_FAILEDTODELETE = "FailedToDelete";
    const C_CIRCULARCOMPANYHIERARCHIES = "CircularCompanyHierarchies";
    const C_DUPLICATEENTRY = "DuplicateEntry";
    const C_DUPLICATEFIELDNAMEINORDERBY = "DuplicateFieldNameInOrderBy";
    const C_CANNOTADJUSTDOCUMENTTYPE = "CannotAdjustDocumentType";
    const C_USERNOACCESS = "UserNoAccess";

    /**
     * Batch errors
     */
    const C_BATCHSALESAUDITMUSTBEZIPPEDERROR = "BatchSalesAuditMustBeZippedError";
    const C_BATCHZIPMUSTCONTAINONEFILEERROR = "BatchZipMustContainOneFileError";
    const C_BATCHINVALIDFILETYPEERROR = "BatchInvalidFileTypeError";
    const C_BATCHCANNOTSAVEBATCHFILE = "BatchCannotSaveBatchFile";
    const C_BATCHCANNOTGETBATCHFILE = "BatchCannotGetBatchFile";
    const C_BATCHCANNOTDELETEBATCHFILE = "BatchCannotDeleteBatchFile";
    const C_BATCHMUSTCONTAINONEFILE = "BatchMustContainOneFile";
    const C_MISSINGBATCHFILECONTENT = "MissingBatchFileContent";

    /**
     * Point Of Sale API exceptions
     */
    const C_POINTOFSALEFILESIZE = "PointOfSaleFileSize";
    const C_POINTOFSALESETUP = "PointOfSaleSetup";
    const C_INVALIDINPUTDATE = "InvalidInputDate";
    const C_REQUESTEDFILENOTEXIST = "RequestedFileNotExist";

    /**
     * Errors in Soap V1 Passthrough / GetTax calls
     */
    const C_GETTAXERROR = "GetTaxError";
    const C_ADDRESSCONFLICTEXCEPTION = "AddressConflictException";
    const C_DOCUMENTCODECONFLICT = "DocumentCodeConflict";
    const C_MISSINGADDRESS = "MissingAddress";
    const C_INVALIDPARAMETER = "InvalidParameter";
    const C_INVALIDPARAMETERVALUE = "InvalidParameterValue";
    const C_COMPANYCODECONFLICT = "CompanyCodeConflict";
    const C_DOCUMENTFETCHLIMIT = "DocumentFetchLimit";
    const C_ADDRESSINCOMPLETE = "AddressIncomplete";
    const C_ADDRESSLOCATIONNOTFOUND = "AddressLocationNotFound";
    const C_MISSINGLINE = "MissingLine";
    const C_INVALIDADDRESSTEXTCASE = "InvalidAddressTextCase";
    const C_DOCUMENTNOTCOMMITTED = "DocumentNotCommitted";
    const C_MULTIDOCUMENTTYPESERROR = "MultiDocumentTypesError";
    const C_INVALIDDOCUMENTTYPESTOFETCH = "InvalidDocumentTypesToFetch";
    const C_TIMEOUTREQUESTED = "TimeoutRequested";
    const C_INVALIDADDRESS = "InvalidAddress";
    const C_INVALIDPOSTALCODE = "InvalidPostalCode";

    /**
     * Represents a malformed document fetch command
     */
    const C_BADDOCUMENTFETCH = "BadDocumentFetch";
    const C_CANNOTCHANGEFILINGSTATUS = "CannotChangeFilingStatus";

    /**
     * Represents a SQL server timeout error / deadlock error
     */
    const C_SERVERUNREACHABLE = "ServerUnreachable";

    /**
     * Partner API error codes
     */
    const C_SUBSCRIPTIONREQUIRED = "SubscriptionRequired";
    const C_ACCOUNTEXISTS = "AccountExists";
    const C_INVITATIONONLY = "InvitationOnly";
    const C_FREETRIALNOTAVAILABLE = "FreeTrialNotAvailable";
    const C_ACCOUNTEXISTSDIFFERENTEMAIL = "AccountExistsDifferentEmail";
    const C_AVALARAIDENTITYAPIERROR = "AvalaraIdentityApiError";
    const C_INVALIDIPADDRESS = "InvalidIPAddress";

    /**
     * Refund API error codes
     */
    const C_INVALIDDOCUMENTSTATUSFORREFUND = "InvalidDocumentStatusForRefund";
    const C_REFUNDTYPEANDPERCENTAGEMISMATCH = "RefundTypeAndPercentageMismatch";
    const C_INVALIDDOCUMENTTYPEFORREFUND = "InvalidDocumentTypeForRefund";
    const C_REFUNDTYPEANDLINEMISMATCH = "RefundTypeAndLineMismatch";
    const C_REFUNDLINESREQUIRED = "RefundLinesRequired";
    const C_INVALIDREFUNDTYPE = "InvalidRefundType";
    const C_REFUNDPERCENTAGEFORTAXONLY = "RefundPercentageForTaxOnly";
    const C_LINENOOUTOFRANGE = "LineNoOutOfRange";
    const C_REFUNDPERCENTAGEOUTOFRANGE = "RefundPercentageOutOfRange";
    const C_REFUNDPERCENTAGEMISSING = "RefundPercentageMissing";

    /**
     * Free API error codes
     */
    const C_MUSTUSECREATETRANSACTION = "MustUseCreateTransaction";

    /**
     * Filing Calendar Error Codes
     */
    const C_FILINGCALENDARCANNOTBEDELETED = "FilingCalendarCannotBeDeleted";
    const C_INVALIDEFFECTIVEDATE = "InvalidEffectiveDate";
    const C_NONOUTLETFORM = "NonOutletForm";
    const C_OVERLAPPINGFILINGCALENDAR = "OverlappingFilingCalendar";

    /**
     * Location error codes
     */
    const C_QUESTIONNOTNEEDEDFORTHISADDRESS = "QuestionNotNeededForThisAddress";
    const C_QUESTIONNOTVALIDFORTHISADDRESS = "QuestionNotValidForThisAddress";

    /**
     * Create or update transaction error codes
     */
    const C_CANNOTMODIFYLOCKEDTRANSACTION = "CannotModifyLockedTransaction";
    const C_LINEALREADYEXISTS = "LineAlreadyExists";
    const C_LINEDOESNOTEXIST = "LineDoesNotExist";
    const C_LINESNOTSPECIFIED = "LinesNotSpecified";

    /**
     * Exempt cert error codes
     */
    const C_INVALIDBUSINESSTYPE = "InvalidBusinessType";
    const C_CANNOTMODIFYEXEMPTCERT = "CannotModifyExemptCert";
    const C_CERTCAPTUREFIELDVALIDATIONERROR = "CertCaptureFieldValidationError";
    const C_CERTCAPTUREERROR = "CertCaptureError";
    const C_MISSINGREQUIREDFIELDS = "MissingRequiredFields";
    const C_CERTCAPTURENOTCONFIGUREDERROR = "CertCaptureNotConfiguredError";
    const C_ADDRELATIONSHIPSERROR = "AddRelationshipsError";
    const C_MISSINGEXPOSUREZONE = "MissingExposureZone";
    const C_CONFLICTINGEXPOSUREZONE = "ConflictingExposureZone";
    const C_MISSINGFIELDTOCREATEEXPOSUREZONE = "MissingFieldToCreateExposureZone";
    const C_MISSINGEXEMPTREASON = "MissingExemptReason";
    const C_INVALIDEXEMPTREASON = "InvalidExemptReason";
    const C_INVALIDCERTCAPTUREOPERATION = "InvalidCertCaptureOperation";
    const C_CONFLICTINGFIELDS = "ConflictingFields";
    const C_INVALIDPDFORIMAGEFILE = "InvalidPdfOrImageFile";
    const C_INVALIDCOVERLETTERTITLE = "InvalidCoverLetterTitle";
    const C_ACCOUNTNOTPROVISIONED = "AccountNotProvisioned";

    /**
     * Multi document error codes
     */
    const C_TRANSACTIONNOTCANCELLED = "TransactionNotCancelled";
    const C_TOOMANYTRANSACTIONS = "TooManyTransactions";
    const C_ONLYTAXDATEOVERRIDEISALLOWED = "OnlyTaxDateOverrideIsAllowed";
    const C_TRANSACTIONALREADYEXISTS = "TransactionAlreadyExists";
    const C_DATEMISMATCH = "DateMismatch";
    const C_INVALIDDOCUMENTSTATUSFORVERIFY = "InvalidDocumentStatusForVerify";
    const C_TOTALAMOUNTMISMATCH = "TotalAmountMismatch";
    const C_TOTALTAXMISMATCH = "TotalTaxMismatch";
    const C_INVALIDDOCUMENTSTATUSFORCOMMIT = "InvalidDocumentStatusForCommit";
    const C_INVALIDDOCUMENTTYPE = "InvalidDocumentType";
    const C_MULTIDOCUMENTPARTIALLYLOCKED = "MultiDocumentPartiallyLocked";
    const C_TRANSACTIONISCOMMITTED = "TransactionIsCommitted";

    /**
     * Communications Tax error codes
     */
    const C_COMMSCONFIGCLIENTIDMISSING = "CommsConfigClientIdMissing";
    const C_COMMSCONFIGCLIENTIDBADVALUE = "CommsConfigClientIdBadValue";

    /**
     * BizTech API error codes
     */
    const C_BIZTECHCUSTOMERACCOUNTFAILURE = "BizTechCustomerAccountFailure";
    const C_BIZTECHOPPORTUNITYCREATIONFAILURE = "BizTechOpportunityCreationFailure";

    /**
     * Account Activate error codes
     */
    const C_ACCOUNTINNEWSTATUSEXCEPTION = "AccountInNewStatusException";

    /**
     * Worksheet Exception
     */
    const C_WORKSHEETEXCEPTION = "WorksheetException";

}


/**
 * Severity of message
 */
class SeverityLevel
{

    /**
     * Operation succeeded
     */
    const C_SUCCESS = "Success";

    /**
     * Warnings occured, operation succeeded
     */
    const C_WARNING = "Warning";

    /**
     * Errors occured, operation failed
     */
    const C_ERROR = "Error";

    /**
     * Unexpected exceptions occurred, operation failed
     */
    const C_EXCEPTION = "Exception";

}


/**
 * Represents the type of welcome email for the users
 */
class WelcomeEmail
{

    /**
     * Normal
     */
    const C_NORMAL = "Normal";

    /**
     * Suppressed
     */
    const C_SUPPRESSED = "Suppressed";

    /**
     * Custom
     */
    const C_CUSTOM = "Custom";

}


/**
 * The address resolution quality of an address validation result
 */
class ResolutionQuality
{

    /**
     * Location was not geocoded
     */
    const C_NOTCODED = "NotCoded";

    /**
     * Location was already geocoded on the request
     */
    const C_EXTERNAL = "External";

    /**
     * Avalara-defined country centroid
     */
    const C_COUNTRYCENTROID = "CountryCentroid";

    /**
     * Avalara-defined state / province centroid
     */
    const C_REGIONCENTROID = "RegionCentroid";

    /**
     * Geocoded at a level more coarse than a PostalCentroid1
     */
    const C_PARTIALCENTROID = "PartialCentroid";

    /**
     * Largest postal code (zip5 in US, left three in CA, etc
     */
    const C_POSTALCENTROIDGOOD = "PostalCentroidGood";

    /**
     * Better postal code (zip7 in US)
     */
    const C_POSTALCENTROIDBETTER = "PostalCentroidBetter";

    /**
     * Best postal code (zip9 in US, complete postal code elsewhere)
     */
    const C_POSTALCENTROIDBEST = "PostalCentroidBest";

    /**
     * Nearest intersection
     */
    const C_INTERSECTION = "Intersection";

    /**
     * Interpolated to rooftop
     */
    const C_INTERPOLATED = "Interpolated";

    /**
     * Assumed to be rooftop level, non-interpolated
     */
    const C_ROOFTOP = "Rooftop";

    /**
     * Pulled from a static list of geocodes for specific jurisdictions
     */
    const C_CONSTANT = "Constant";

}


/**
 * Jurisdiction Type
 */
class JurisdictionType
{

    /**
     * Country
     */
    const C_COUNTRY = "Country";

    /**
     * Deprecated
     */
    const C_COMPOSITE = "Composite";

    /**
     * State
     */
    const C_STATE = "State";

    /**
     * County
     */
    const C_COUNTY = "County";

    /**
     * City
     */
    const C_CITY = "City";

    /**
     * Special Tax Jurisdiction
     */
    const C_SPECIAL = "Special";

}


/**
 * The type of data contained in this batch
 */
class BatchType
{
    const C_AVACERTUPDATE = "AvaCertUpdate";
    const C_AVACERTUPDATEALL = "AvaCertUpdateAll";
    const C_BATCHMAINTENANCE = "BatchMaintenance";
    const C_COMPANYLOCATIONIMPORT = "CompanyLocationImport";
    const C_DOCUMENTIMPORT = "DocumentImport";
    const C_EXEMPTCERTIMPORT = "ExemptCertImport";
    const C_ITEMIMPORT = "ItemImport";
    const C_SALESAUDITEXPORT = "SalesAuditExport";
    const C_SSTPTESTDECKIMPORT = "SstpTestDeckImport";
    const C_TAXRULEIMPORT = "TaxRuleImport";

    /**
     * This batch type represents tax transaction data being uploaded to AvaTax. Each line in the batch represents a single transaction
     *  or a line in a multi-line transaction. For reference, see [Batched Transactions in REST v2](http://developer.avalara.com/blog/2016/10/24/batch-transaction-upload-in-rest-v2)
     */
    const C_TRANSACTIONIMPORT = "TransactionImport";
    const C_UPCBULKIMPORT = "UPCBulkImport";
    const C_UPCVALIDATIONIMPORT = "UPCValidationImport";

}


/**
 * The status of a batch file
 */
class BatchStatus
{

    /**
     * Batch file has been received and is in the queue to be processed.
     */
    const C_WAITING = "Waiting";

    /**
     * Batch file experienced system errors and cannot be processed.
     */
    const C_SYSTEMERRORS = "SystemErrors";

    /**
     * Batch file is cancelled
     */
    const C_CANCELLED = "Cancelled";

    /**
     * Batch file has been completely processed.
     */
    const C_COMPLETED = "Completed";

    /**
     * Batch file is currently being created.
     */
    const C_CREATING = "Creating";

    /**
     * Batch file has been deleted.
     */
    const C_DELETED = "Deleted";

    /**
     * Batch file was processed with some errors.
     */
    const C_ERRORS = "Errors";

    /**
     * Batch processing was paused.
     */
    const C_PAUSED = "Paused";

    /**
     * Batch is currently being processed.
     */
    const C_PROCESSING = "Processing";

}


/**
 * The way of delivering request
 */
class CertificateRequestDeliveryMethod
{

    /**
     * The invitation will be sent via email to the recipient's email address.
     */
    const C_EMAIL = "Email";

    /**
     * The invitation will be sent via facsimile to the recipient's facsimile phone number.
     *  
     *  Facsimile transmission make take time to process and deliver via phone lines.
     */
    const C_FAX = "Fax";

    /**
     * The request will be processed and turned into a web link (URL) which the user can click on to visit the CertExpress site and immediately
     *  begin entering data about their certificates.
     */
    const C_DOWNLOAD = "Download";

}


/**
 * Indicates the status of a CertExpress invitation link.
 */
class CertExpressInvitationStatus
{

    /**
     * The CertExpress website is currently building a landing page for the customer. Please
     *  wait about 10 seconds and fetch this request again to see when it will be ready.
     */
    const C_INPROGRESS = "InProgress";

    /**
     * Indicates that the CertExpress invitation has been completed and is ready to use.
     */
    const C_READY = "Ready";

}


/**
 * 
 */
class CertCaptureProvisionStatus
{

    /**
     * Account and company are provisioned
     */
    const C_FINISHED = "Finished";

    /**
     * Account are not provisioned
     */
    const C_NOTSTARTED = "NotStarted";

    /**
     * Provision job is being queued
     *  This could also be an indication that some companies under an account has been provisioned, while others
     *  under the same account has not.
     */
    const C_INPROGRESS = "InProgress";

    /**
     * The account is put into provisioned queue.
     */
    const C_QUEUED = "Queued";

}


/**
 * Choice of rounding level for a transaction
 */
class RoundingLevelId
{

    /**
     * Round tax on each line separately
     */
    const C_LINE = "Line";

    /**
     * Round tax at the document level
     */
    const C_DOCUMENT = "Document";

}


/**
 * TaxDependencyLevelId
 */
class TaxDependencyLevelId
{

    /**
     * Document
     */
    const C_DOCUMENT = "Document";

    /**
     * State
     */
    const C_STATE = "State";

    /**
     * TaxRegion
     */
    const C_TAXREGION = "TaxRegion";

    /**
     * Address
     */
    const C_ADDRESS = "Address";

}


/**
 * Indicates whether this address refers to a person or an business
 */
class AddressTypeId
{

    /**
     * A business location, for example a store, warehouse, or office.
     */
    const C_LOCATION = "Location";

    /**
     * A person's address who performs sales tasks for the company remotely from an office.
     */
    const C_SALESPERSON = "Salesperson";

}


/**
 * The type of address represented by this object
 */
class AddressCategoryId
{

    /**
     * Address refers to a storefront location
     */
    const C_STOREFRONT = "Storefront";

    /**
     * Address refers to a main office of this company
     */
    const C_MAINOFFICE = "MainOffice";

    /**
     * Address refers to a warehouse or other non-public location
     */
    const C_WAREHOUSE = "Warehouse";

    /**
     * Address refers to a location for a single salesperson
     */
    const C_SALESPERSON = "Salesperson";

    /**
     * Address is a type not reflected in the other lists
     */
    const C_OTHER = "Other";

}


/**
 * Types of jurisdiction referenced in a transaction
 */
class JurisTypeId
{

    /**
     * State
     */
    const C_STA = "STA";

    /**
     * County
     */
    const C_CTY = "CTY";

    /**
     * City
     */
    const C_CIT = "CIT";

    /**
     * Special
     */
    const C_STJ = "STJ";

    /**
     * Country
     */
    const C_CNT = "CNT";

}


/**
 * Describes the different types of statuses which describe an entity (company).
 */
class NexusTypeId
{

    /**
     * Indicates no nexus
     */
    const C_NONE = "None";

    /**
     * Indicates the entity is voluntarily collecting tax (default)
     *  
     *  This has replaced Collect
     */
    const C_SALESORSELLERSUSETAX = "SalesOrSellersUseTax";

    /**
     * Indicates the entity is required to collect tax in the state
     *  
     *  This has replaced Legal
     */
    const C_SALESTAX = "SalesTax";

    /**
     * Indicates the entity is registered as a Volunteer in an SST state.
     *  Only your SST administrator may set this option.
     */
    const C_SSTVOLUNTEER = "SSTVolunteer";

    /**
     * Indicates the entity is registered as a Non-Volunteer in an SST state.
     *  Only your SST administrator may set this option.
     */
    const C_SSTNONVOLUNTEER = "SSTNonVolunteer";

}


/**
 * Sourcing
 */
class Sourcing
{

    /**
     * Mixed sourcing, for states that do both origin and destination calculation
     */
    const C_MIXED = "Mixed";

    /**
     * Destination
     */
    const C_DESTINATION = "Destination";

    /**
     * Origin
     */
    const C_ORIGIN = "Origin";

}


/**
 * Describes nexus type id
 */
class LocalNexusTypeId
{

    /**
     * Only the specific nexus objects declared for this company are declared.
     */
    const C_SELECTED = "Selected";

    /**
     * Customer declares nexus in all state administered taxing authorities.
     *  
     *  This value only takes effect if you set `hasLocalNexus` = true.
     */
    const C_STATEADMINISTERED = "StateAdministered";

    /**
     * Customer declares nexus in all local taxing authorities. 
     *  
     *  This value only takes effect if you set `hasLocalNexus` = true.
     */
    const C_ALL = "All";

}


/**
 * This data type is only used when an object must "Match" tax types. By specifying options here,
 *  you can indicate which tax types will match for the purposes of this object.
 *  For example, if you specify BothSalesAndUseTax, this value matches with both sales and seller's use tax.
 */
class MatchingTaxType
{

    /**
     * Match medical excise type
     */
    const C_EXCISE = "Excise";

    /**
     * Match Lodging tax type
     */
    const C_LODGING = "Lodging";

    /**
     * Match bottle tax type
     */
    const C_BOTTLE = "Bottle";

    /**
     * Match all tax types
     */
    const C_ALL = "All";

    /**
     * Match both Sales and Use Tax only
     */
    const C_BOTHSALESANDUSETAX = "BothSalesAndUseTax";

    /**
     * Match Consumer Use Tax only
     */
    const C_CONSUMERUSETAX = "ConsumerUseTax";

    /**
     * Match both Consumer Use and Seller's Use Tax types
     */
    const C_CONSUMERSUSEANDSELLERSUSETAX = "ConsumersUseAndSellersUseTax";

    /**
     * Match both Consumer Use and Sales Tax types
     */
    const C_CONSUMERUSEANDSALESTAX = "ConsumerUseAndSalesTax";

    /**
     * Match Fee tax types only
     */
    const C_FEE = "Fee";

    /**
     * Match VAT Input Tax only
     */
    const C_VATINPUTTAX = "VATInputTax";

    /**
     * Match VAT Nonrecoverable Input Tax only
     */
    const C_VATNONRECOVERABLEINPUTTAX = "VATNonrecoverableInputTax";

    /**
     * Match VAT Output Tax only
     */
    const C_VATOUTPUTTAX = "VATOutputTax";

    /**
     * Match Rental tax types only
     */
    const C_RENTAL = "Rental";

    /**
     * Match Sales Tax only
     */
    const C_SALESTAX = "SalesTax";

    /**
     * Match Seller's Use Tax only
     */
    const C_USETAX = "UseTax";

}


/**
 * 
 */
class RateType
{
    const C_REDUCEDA = "ReducedA";
    const C_REDUCEDB = "ReducedB";
    const C_FOOD = "Food";
    const C_GENERAL = "General";
    const C_INCREASEDSTANDARD = "IncreasedStandard";
    const C_LINENRENTAL = "LinenRental";
    const C_MEDICAL = "Medical";
    const C_PARKING = "Parking";
    const C_SUPERREDUCED = "SuperReduced";
    const C_REDUCEDR = "ReducedR";
    const C_STANDARD = "Standard";
    const C_ZERO = "Zero";

}


/**
 * TaxRuleTypeId
 */
class TaxRuleTypeId
{

    /**
     * RateRule
     */
    const C_RATERULE = "RateRule";

    /**
     * RateOverrideRule
     */
    const C_RATEOVERRIDERULE = "RateOverrideRule";

    /**
     * BaseRule
     */
    const C_BASERULE = "BaseRule";

    /**
     * ExemptEntityRule
     */
    const C_EXEMPTENTITYRULE = "ExemptEntityRule";

    /**
     * ProductTaxabilityRule
     */
    const C_PRODUCTTAXABILITYRULE = "ProductTaxabilityRule";

    /**
     * NexusRule
     */
    const C_NEXUSRULE = "NexusRule";

}


/**
 * Exempt Cert type
 */
class ExemptCertTypeId
{

    /**
     * Blanked certificate
     */
    const C_BLANKET = "Blanket";

    /**
     * Single use
     */
    const C_SINGLEUSE = "SingleUse";

}


/**
 * Status for this exempt certificate
 */
class ExemptCertStatusId
{

    /**
     * Inactive certificate
     */
    const C_INACTIVE = "Inactive";

    /**
     * Active certificate
     */
    const C_ACTIVE = "Active";

    /**
     * Expired certificate
     */
    const C_EXPIRED = "Expired";

    /**
     * Revoked certificate
     */
    const C_REVOKED = "Revoked";

}


/**
 * Exempt certificate review status
 */
class ExemptCertReviewStatusId
{

    /**
     * Review pending
     */
    const C_PENDING = "Pending";

    /**
     * Certificate was accepted
     */
    const C_ACCEPTED = "Accepted";

    /**
     * Certificate was rejected
     */
    const C_REJECTED = "Rejected";

}


/**
 * Indicates whether Avalara Managed Returns has begun filing for this company.
 */
class CompanyFilingStatus
{

    /**
     * This company is not a reporting entity and cannot file taxes. To change this behavior, you must mark
     *  the company as a reporting entity.
     */
    const C_NOREPORTING = "NoReporting";

    /**
     * This company is a reporting entity, but Avalara is not currently filing tax returns for this company.
     */
    const C_NOTYETFILING = "NotYetFiling";

    /**
     * The customer has requested that Avalara Managed Returns begin filing for this company, however filing has
     *  not yet started. Avalara's compliance team is reviewing this request and will update the company to
     *  first filing status when complete.
     */
    const C_FILINGREQUESTED = "FilingRequested";

    /**
     * Avalara has begun filing tax returns for this company. Normally, this status will change to `Active` after 
     *  one month of successful filing of tax returns.
     */
    const C_FIRSTFILING = "FirstFiling";

    /**
     * Avalara currently files tax returns for this company.
     */
    const C_ACTIVE = "Active";

    /**
     * This company has not been configured for compliance
     */
    const C_NOTCONFIGUREDFORCOMPLIANCE = "NotConfiguredForCompliance";

}


/**
 * The data type that must be passed in a parameter bag
 */
class ParameterBagDataType
{

    /**
     * This data type is a string.
     */
    const C_STRING = "String";

    /**
     * This data type is either 'true' or 'false'.
     */
    const C_BOOLEAN = "Boolean";

    /**
     * This data type is a numeric value. It can include decimals.
     */
    const C_NUMERIC = "Numeric";

}


/**
 * Type of verification task
 */
class ScraperType
{

    /**
     * Indicates that is is a login type
     */
    const C_LOGIN = "Login";

    /**
     * Indicates that it is a Customer DOR Data type
     */
    const C_CUSTOMERDORDATA = "CustomerDorData";

}


/**
 * Jurisdiction boundary precision level found for address. This depends on the accuracy of the address
 *  as well as the precision level of the state provided jurisdiction boundaries.
 */
class BoundaryLevel
{

    /**
     * Street address precision
     */
    const C_ADDRESS = "Address";

    /**
     * 9-digit zip precision
     */
    const C_ZIP9 = "Zip9";

    /**
     * 5-digit zip precision
     */
    const C_ZIP5 = "Zip5";

}


/**
 * Indicates the behavior of a tax form for a company with multiple places of business.
 *  
 *  Some tax authorities require that a separate form must be filed for each place of business.
 */
class OutletTypeId
{

    /**
     * File a single return per cycle for your entire business.
     */
    const C_NONE = "None";

    /**
     * You may file separate forms for each outlet; contact the tax authority for more details about location based reporting requirements.
     */
    const C_SCHEDULE = "Schedule";

    /**
     * You may file separate forms for each outlet; contact the tax authority for more details about location based reporting requirements.
     */
    const C_DUPLICATE = "Duplicate";

    /**
     * File a single return, but you must have a line item for each place of business.
     */
    const C_CONSOLIDATED = "Consolidated";

}


/**
 * A list of possible AvaFile filing types.
 */
class FilingTypeId
{

    /**
     * Denotes the tax return is being filed on paper.
     */
    const C_PAPERRETURN = "PaperReturn";

    /**
     * Denotes the tax return is being filed via electronic means; excludes SST electronic filing.
     */
    const C_ELECTRONICRETURN = "ElectronicReturn";

    /**
     * Denotes the tax return is an SST filing.
     */
    const C_SER = "SER";

    /**
     * Denotes a return is paid via EFT and filed on paper without payment.
     */
    const C_EFTPAPER = "EFTPaper";

    /**
     * Denotes a return is paid via phone and filed on paper without payment.
     */
    const C_PHONEPAPER = "PhonePaper";

    /**
     * Denotes a return is prepared but delivered to the customer for filing and payment.
     */
    const C_SIGNATUREREADY = "SignatureReady";

    /**
     * Denotes a return which is filed online but paid by check.
     */
    const C_EFILECHECK = "EfileCheck";

}


/**
 * Filing Request Status types
 */
class FilingRequestStatus
{

    /**
     * Customer is building a request for a new filing calendar
     */
    const C_NEW = "New";

    /**
     * Customer’s information validated before submitting to go live. All required information as per state and form selection is entered.
     */
    const C_VALIDATED = "Validated";

    /**
     * Customer submitted a request for a new filing calendar
     */
    const C_PENDING = "Pending";

    /**
     * Filing calender is active
     */
    const C_ACTIVE = "Active";

    /**
     * Customer requested to deactivate filing calendar
     */
    const C_PENDINGSTOP = "PendingStop";

    /**
     * Filing calendar is inactive
     */
    const C_INACTIVE = "Inactive";

    /**
     * This indicates that there is a new change request.
     */
    const C_CHANGEREQUEST = "ChangeRequest";

    /**
     * This indicates that the change request was approved.
     */
    const C_REQUESTAPPROVED = "RequestApproved";

    /**
     * This indicates that compliance rejected the request.
     */
    const C_REQUESTDENIED = "RequestDenied";

}


/**
 * Accrual types
 */
class AccrualType
{

    /**
     * Filing indicates that this tax return should be filed with its tax authority by its due date. For example, if you file annually, you will have eleven months of Accrual returns and one Filing return.
     */
    const C_FILING = "Filing";

    /**
     * An Accrual filing indicates taxes that are accrued, intended to be filed on a future tax return. For example, if you file annually, you will have eleven months of Accrual returns and one Filing return.
     */
    const C_ACCRUAL = "Accrual";

}


/**
 * Filing worksheet Type
 */
class WorksheetTypeId
{

    /**
     * The original filing for a period
     */
    const C_ORIGINAL = "Original";

    /**
     * Represents an amended filing for a period
     */
    const C_AMENDED = "Amended";

    /**
     * Represents a test filing
     */
    const C_TEST = "Test";

}


/**
 * 
 */
class AdjustmentPeriodTypeId
{
    const C_NONE = "None";
    const C_CURRENTPERIOD = "CurrentPeriod";
    const C_NEXTPERIOD = "NextPeriod";

}


/**
 * 
 */
class AdjustmentTypeId
{
    const C_OTHER = "Other";
    const C_CURRENTPERIODROUNDING = "CurrentPeriodRounding";
    const C_PRIORPERIODROUNDING = "PriorPeriodRounding";
    const C_CURRENTPERIODDISCOUNT = "CurrentPeriodDiscount";
    const C_PRIORPERIODDISCOUNT = "PriorPeriodDiscount";
    const C_CURRENTPERIODCOLLECTION = "CurrentPeriodCollection";
    const C_PRIORPERIODCOLLECTION = "PriorPeriodCollection";
    const C_PENALTY = "Penalty";
    const C_INTEREST = "Interest";
    const C_DISCOUNT = "Discount";
    const C_ROUNDING = "Rounding";
    const C_CSPFEE = "CspFee";

}


/**
 * 
 */
class PaymentAccountTypeId
{
    const C_NONE = "None";
    const C_ACCOUNTSRECEIVABLEACCOUNTSPAYABLE = "AccountsReceivableAccountsPayable";
    const C_ACCOUNTSRECEIVABLE = "AccountsReceivable";
    const C_ACCOUNTSPAYABLE = "AccountsPayable";

}


/**
 * Indicates the type of payments
 */
class PaymentType
{

    /**
     * The payment is for the current payment
     */
    const C_CURRENTPERIOD = "CurrentPeriod";

    /**
     * The payment is a prepayment
     */
    const C_PREPAYMENT = "Prepayment";

    /**
     * The payment is a prior payment
     */
    const C_PRIORPAYMENT = "PriorPayment";

    /**
     * The payment is a prior CSP fee
     */
    const C_PRIORCSPFEE = "PriorCspFee";

}


/**
 * Document Status
 */
class DocumentStatus
{

    /**
     * Temporary document not saved (SalesOrder, PurchaseOrder)
     */
    const C_TEMPORARY = "Temporary";

    /**
     * Saved document (SalesInvoice or PurchaseInvoice) ready to be posted
     */
    const C_SAVED = "Saved";

    /**
     * A posted document (not committed)
     */
    const C_POSTED = "Posted";

    /**
     * A posted document that has been committed
     */
    const C_COMMITTED = "Committed";

    /**
     * A Committed document that has been cancelled
     */
    const C_CANCELLED = "Cancelled";

    /**
     * A document that has been adjusted
     */
    const C_ADJUSTED = "Adjusted";

    /**
     * A document which is in Queue status and processed later
     */
    const C_QUEUED = "Queued";

    /**
     * A document which is Pending for Approval
     */
    const C_PENDINGAPPROVAL = "PendingApproval";

    /**
     * Any status (for searching)
     */
    const C_ANY = "Any";

}


/**
 * TaxOverrideTypeId
 */
class TaxOverrideTypeId
{

    /**
     * No override
     */
    const C_NONE = "None";

    /**
     * Tax was overriden by the client
     */
    const C_TAXAMOUNT = "TaxAmount";

    /**
     * Entity exemption was ignored (e.g. item was consumed)
     */
    const C_EXEMPTION = "Exemption";

    /**
     * Only the tax date was overriden
     */
    const C_TAXDATE = "TaxDate";

    /**
     * To support Consumer Use Tax
     */
    const C_ACCRUEDTAXAMOUNT = "AccruedTaxAmount";

    /**
     * Derive the taxable amount from the tax amount
     */
    const C_DERIVETAXABLE = "DeriveTaxable";

}


/**
 * Indicates the type of adjustment that was performed on a transaction
 */
class AdjustmentReason
{

    /**
     * The transaction has not been adjusted
     */
    const C_NOTADJUSTED = "NotAdjusted";

    /**
     * A sourcing issue existed which caused the transaction to be adjusted
     */
    const C_SOURCINGISSUE = "SourcingIssue";

    /**
     * Transaction was adjusted to reconcile it with a general ledger
     */
    const C_RECONCILEDWITHGENERALLEDGER = "ReconciledWithGeneralLedger";

    /**
     * Transaction was adjusted after an exemption certificate was applied
     */
    const C_EXEMPTCERTAPPLIED = "ExemptCertApplied";

    /**
     * Transaction was adjusted when the price of an item changed
     */
    const C_PRICEADJUSTED = "PriceAdjusted";

    /**
     * Transaction was adjusted due to a product return
     */
    const C_PRODUCTRETURNED = "ProductReturned";

    /**
     * Transaction was adjusted due to a product exchange
     */
    const C_PRODUCTEXCHANGED = "ProductExchanged";

    /**
     * Transaction was adjusted due to bad or uncollectable debt
     */
    const C_BADDEBT = "BadDebt";

    /**
     * Transaction was adjusted for another reason not specified
     */
    const C_OTHER = "Other";

    /**
     * Offline
     */
    const C_OFFLINE = "Offline";

}


/**
 * Tax type
 */
class TaxType
{

    /**
     * Match Lodging tax type
     */
    const C_LODGING = "Lodging";

    /**
     * Match bottle tax type
     */
    const C_BOTTLE = "Bottle";

    /**
     * EWaste tax type
     */
    const C_EWASTE = "EWaste";

    /**
     * LandedCost tax type
     */
    const C_LANDEDCOST = "LandedCost";

    /**
     * Consumer Use Tax
     */
    const C_CONSUMERUSE = "ConsumerUse";

    /**
     * Medical Excise Tax
     */
    const C_EXCISE = "Excise";

    /**
     * Fee - PIFs (Public Improvement Fees) and RSFs (Retail Sales Fees)
     */
    const C_FEE = "Fee";

    /**
     * VAT/GST Input tax
     */
    const C_INPUT = "Input";

    /**
     * VAT/GST Nonrecoverable Input tax
     */
    const C_NONRECOVERABLE = "Nonrecoverable";

    /**
     * VAT/GST Output tax
     */
    const C_OUTPUT = "Output";

    /**
     * Rental Tax
     */
    const C_RENTAL = "Rental";

    /**
     * Sales tax
     */
    const C_SALES = "Sales";

    /**
     * Use tax
     */
    const C_USE = "Use";

}


/**
 * Refund types
 */
class RefundType
{

    /**
     * Refund the whole transaction.
     */
    const C_FULL = "Full";

    /**
     * Refund only specific lines from the original a transaction.
     */
    const C_PARTIAL = "Partial";

    /**
     * Only refund the tax part of the transaction.
     */
    const C_TAXONLY = "TaxOnly";

    /**
     * Refund a percentage of the value of this transaction.
     */
    const C_PERCENTAGE = "Percentage";

}


/**
 * Service modes for tax calculation when using an AvaLocal server.
 */
class ServiceMode
{

    /**
     * Automatically use local or remote (default)
     */
    const C_AUTOMATIC = "Automatic";

    /**
     * Local server only
     */
    const C_LOCAL = "Local";

    /**
     * Remote server only
     */
    const C_REMOTE = "Remote";

}


/**
 * Indicates the level of detail requested from a tax API call
 */
class TaxDebugLevel
{

    /**
     * User requests the normal level of debug information when creating a tax transaction
     */
    const C_NORMAL = "Normal";

    /**
     * User requests additional diagnostic information when creating a tax transaction
     */
    const C_DIAGNOSTIC = "Diagnostic";

}


/**
 * TaxOverride reasons
 */
class TaxOverrideType
{

    /**
     * No override
     */
    const C_NONE = "None";

    /**
     * Tax was overriden by the client
     */
    const C_TAXAMOUNT = "TaxAmount";

    /**
     * Entity exemption was ignored (e.g. item was consumed)
     */
    const C_EXEMPTION = "Exemption";

    /**
     * Only the tax date was overriden
     */
    const C_TAXDATE = "TaxDate";

    /**
     * To support Consumer Use Tax
     */
    const C_ACCRUEDTAXAMOUNT = "AccruedTaxAmount";

    /**
     * Derive the taxable amount from the tax amount
     */
    const C_DERIVETAXABLE = "DeriveTaxable";

}


/**
 * Reason code for voiding or cancelling a transaction
 */
class VoidReasonCode
{

    /**
     * Unspecified reason
     */
    const C_UNSPECIFIED = "Unspecified";

    /**
     * Post operation failed - Document status will be changed to unposted
     */
    const C_POSTFAILED = "PostFailed";

    /**
     * Document deleted - If committed, document status will be changed to Cancelled. If not committed, document will be
     *  deleted.
     */
    const C_DOCDELETED = "DocDeleted";

    /**
     * Document has been voided and DocStatus will be set to Cancelled
     */
    const C_DOCVOIDED = "DocVoided";

    /**
     * AdjustTax operation has been cancelled. Adjustment will be reversed.
     */
    const C_ADJUSTMENTCANCELLED = "AdjustmentCancelled";

}


/**
 * Indicates what level of auditing information is available for a transaction
 */
class ApiCallStatus
{

    /**
     * If the original api call is availabe on S3
     */
    const C_ORIGINALAPICALLAVAILABLE = "OriginalApiCallAvailable";

    /**
     * if the original api call is not available, reconstructed api call should always be available
     */
    const C_RECONSTRUCTEDAPICALLAVAILABLE = "ReconstructedApiCallAvailable";

    /**
     * Any other api call status
     */
    const C_ANY = "Any";

}


/**
 * Filing Frequency types
 */
class NoticeCustomerType
{

    /**
     * AvaTax Returns
     */
    const C_AVATAXRETURNS = "AvaTaxReturns";

    /**
     * Stand Alone
     */
    const C_STANDALONE = "StandAlone";

    /**
     * Strategic
     */
    const C_STRATEGIC = "Strategic";

    /**
     * SST
     */
    const C_SST = "SST";

    /**
     * TrustFile
     */
    const C_TRUSTFILE = "TrustFile";

}


/**
 * Filing Frequency types
 */
class FundingOption
{

    /**
     * Pull
     */
    const C_PULL = "Pull";

    /**
     * Wire
     */
    const C_WIRE = "Wire";

}


/**
 * Filing Frequency types
 */
class NoticePriorityId
{

    /**
     * Immediate Attention Required
     */
    const C_IMMEDIATEATTENTIONREQUIRED = "ImmediateAttentionRequired";

    /**
     * High
     */
    const C_HIGH = "High";

    /**
     * Normal
     */
    const C_NORMAL = "Normal";

    /**
     * Low
     */
    const C_LOW = "Low";

}


/**
 * Comment Types
 */
class CommentType
{

    /**
     * Internal comments are those comments only intended to be for compliance users
     */
    const C_INTERNAL = "Internal";

    /**
     * Customer comments are those comments that both compliance and the customer can read
     */
    const C_CUSTOMER = "Customer";

}


/**
 * Different types of formats allowed for exporting a report
 */
class ReportFormat
{

    /**
     * The Comma Separated Values file format
     */
    const C_CSV = "CSV";

    /**
     * The Extensible Markup Language file format
     */
    const C_XML = "XML";

}


/**
 * The date filter type for report
 *  "RD" for Reporting Date, "DD" for Document Date, "TD" for Tax Date, "PD" for Payment Date
 */
class ReportDateFilter
{

    /**
     * The date when the transaction is posted
     */
    const C_DOCUMENTDATE = "DocumentDate";

    /**
     * The date when the transaction is paid for
     */
    const C_PAYMENTDATE = "PaymentDate";

    /**
     * The date when the transaction is added to report
     */
    const C_REPORTINGDATE = "ReportingDate";

    /**
     * The date when the transaction is being taxed
     */
    const C_TAXDATE = "TaxDate";

}


/**
 * The output DocumentType for a report
 */
class ReportDocType
{

    /**
     * Output all ConsumerUse tax transactions in the report
     */
    const C_CONSUMERUSE = "ConsumerUse";

    /**
     * Output all Sales tax transactions in the report
     */
    const C_SALES = "Sales";

}


/**
 * Indicates the level of companies that can be accessed
 */
class CompanyAccessLevel
{

    /**
     * No permission to access companies.
     */
    const C_NONE = "None";

    /**
     * Permission to access a single company and its children.
     */
    const C_SINGLECOMPANY = "SingleCompany";

    /**
     * Permission to access all companies in a single account.
     */
    const C_SINGLEACCOUNT = "SingleAccount";

    /**
     * Permission to access all companies in all accounts. Reserved for system administration tasks.
     */
    const C_ALLCOMPANIES = "AllCompanies";

}


/**
 * Represents the type of authentication provided to the API call
 */
class AuthenticationTypeId
{

    /**
     * This API call was not authenticated.
     */
    const C_NONE = "None";

    /**
     * This API call was authenticated by your username/password.
     */
    const C_USERNAMEPASSWORD = "UsernamePassword";

    /**
     * This API call was authenticated by your Avalara Account ID and private license key.
     */
    const C_ACCOUNTIDLICENSEKEY = "AccountIdLicenseKey";

    /**
     * This API call was authenticated by OpenID Bearer Token.
     */
    const C_OPENIDBEARERTOKEN = "OpenIdBearerToken";

}
